@@ -1,6 +1,5 @@
-extern crate carol_test as not_carol_test;
-
-pub use not_carol_test::Foo;
+/// This is a struct that foos.
+pub struct Foo;
 
 #[cfg(test)]
 mod tests {
